@@ -13,7 +13,7 @@ use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 use Carp qw/cluck/;
 
-our $VERSION  = 0.96013;
+our $VERSION  = 0.97;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -305,7 +305,7 @@ git-up-to-date - Check that git branches include latest production branch/tag
 
 =head1 VERSION
 
-This documentation refers to git-up-to-date version 0.96013
+This documentation refers to git-up-to-date version 0.97
 
 =head1 SYNOPSIS
 
@@ -345,7 +345,7 @@ This documentation refers to git-up-to-date version 0.96013
                     (Default 1)
 
   -s --branch-status
-                    Shows the status (name, last commiter, last commit date) of
+                    Shows the status (name, last committer, last commit date) of
                     all branches.
   -a --age-limit[=]date
                     With --branch-status limit to only branches created after
@@ -406,10 +406,10 @@ Executes the git workflow command
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-Defaults for this script can be set thought C<git config>
+Defaults for this script can be set through C<git config>
 
  workflow.prod  Sets how a prod release is determined
-                eg the default equavilent is branch=^origin/master$
+                eg the default equivalent is branch=^origin/master$
  workflow.max-history
                 Sets the default C<--max-history> value
 
